==> react-fetch-json-hook-0.1.4.tgz: package/es/use-triggerable-fetch.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

import { useCallback, useContext, useMemo, useState } from 'react';
import fetchJSON from './fetch-json';
import FetchConnectorContext from './FetchConnectorContext';
import actHack from './internal/actHack';
export default function useTriggerableFetch(url) {
  var fetchConnector = useContext(FetchConnectorContext);

  if (!fetchConnector) {
    throw new Error('useFetch should not be used outside <FetchConnectorContext.Provider />');
  }

  var _useState = useState({
    loading: false
  }),
      state = _useState[0],
      setState = _useState[1];

  var trigger = useCallback(
  /*#__PURE__*/
  function () {
    var _ref = _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee(body, options) {
      var data;
      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              actHack(function () {
                return setState({
                  loading: true
                });
              });
              _context.prev = 1;
              _context.next = 4;
              return fetchJSON(url, _extends({}, options, {
                headers: _extends({}, fetchConnector.requestHeaders, options && options.headers),
                body: body
              }));

            case 4:
              data = _context.sent;
              actHack(function () {
                return setState({
                  data: data,
                  loading: false
                });
              });
              return _context.abrupt("return", data);

            case 9:
              _context.prev = 9;
              _context.t0 = _context["catch"](1);
              actHack(function () {
                return setState({
                  error: _context.t0,
                  loading: false
                });
              });
              return _context.abrupt("return", _context.t0);

            case 13:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[1, 9]]);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }(), [url, setState]);
  var result = useMemo(function () {
    return _extends({}, state, {
      trigger: trigger
    });
  }, [state, trigger]);
  return result;
}

==> react-fetch-json-hook-0.1.5.tgz: package/es/use-triggerable-fetch.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

import { useCallback, useContext, useMemo, useState } from 'react';
import fetchJSON from './fetch-json';
import FetchConnectorContext from './FetchConnectorContext';
import actHack from './internal/actHack';
export default function useTriggerableFetch(url, defaultOptions) {
  var fetchConnector = useContext(FetchConnectorContext);

  if (!fetchConnector) {
    throw new Error('useFetch should not be used outside <FetchConnectorContext.Provider />');
  }

  var _useState = useState({
    loading: false
  }),
      state = _useState[0],
      setState = _useState[1];

  var trigger = useCallback(
  /*#__PURE__*/
  function () {
    var _ref = _asyncToGenerator(
    /*#__PURE__*/
    regeneratorRuntime.mark(function _callee(body, options) {
      var data;
      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              actHack(function () {
                return setState({
                  loading: true
                });
              });
              _context.prev = 1;
              _context.next = 4;
              return fetchJSON(url, _extends({}, defaultOptions, options, {
                headers: _extends({}, fetchConnector.requestHeaders, defaultOptions && defaultOptions.headers, options && options.headers),
                body: body
              }));

            case 4:
              data = _context.sent;
              actHack(function () {
                return setState({
                  data: data,
                  loading: false
                });
              });
              return _context.abrupt("return", data);

            case 9:
              _context.prev = 9;
              _context.t0 = _context["catch"](1);
              actHack(function () {
                return setState({
                  error: _context.t0,
                  loading: false
                });
              });
              return _context.abrupt("return", _context.t0);

            case 13:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[1, 9]]);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }(), [url, setState]);
  var result = useMemo(function () {
    return _extends({}, state, {
      trigger: trigger
    });
  }, [state, trigger]);
  return result;
}
